@@ -1,5 +1,9 @@
-__version__ = "1.1.0"
-__author__ = "Pablo Velasco"
+""" NOTE: When bumping up the version number, double-check if you
+need to also bump up the version of the dependencies
+"""
+
+__version__ = "1.2.0"
+__author__ = "Pablo Velasco, Chrysa Papadaniil"
 __author_email__ = "pablo.velasco@nyu.edu"
 __url__ = "https://github.com/cbinyu/bidsphysio"
 __packagename__ = 'bidsphysio.session'
