@@ -24,13 +24,13 @@ from .utils import TESTS_DATA_PATH, file_md5sum
 
 NOW = datetime.now()
 # physio clock delay w.r.t. the scanner clock:
-DELAY = 10 * random.random()
-TIME_BETWEEN_RUNS = 100
-N_RUNS = 3
+DELAY = random.uniform(0, 10)
+TIME_BETWEEN_RUNS = random.uniform(95, 105)
+N_RUNS = random.randint(3, 5)
 # We'll add some jitter to the beginning of the physio recordings:
-JITTER_FACTOR = 0.1
-TR = 3 * random.random()
-N_VOLS = round(100 * random.random())
+JITTER_FACTOR = random.uniform(0.01, 0.1)
+TR = random.uniform(0.5, 3)
+N_VOLS = random.randint(1, 100)
 SECS_IN_DAY = 24 * 60 * 60
 
 
@@ -300,3 +300,51 @@ def test_convert_session(
                         get_physio_data=_get_physio_data,
                         get_physio_acq_time=_get_physio_acq_time,
                         outdir='bar', overwrite=True)
+
+class MockEventData(object):
+    """ Class that mocks an EventData class, so we can mock the class
+        methods without the need to include a full dataset in the tests.
+    """
+    def __init__(self, path=''):
+        self.path = path
+    
+    @staticmethod
+    def save_events_to_bids(path):
+        pass
+
+def test_convert_edf_session(
+                             monkeypatch,
+                             my_mocks,
+                             ):
+    """ Tests for "convert_edf_session"
+    """
+    
+    def _get_physio_data(fname):
+        """ Function to return a MockPhysioData object
+        """
+        return MockPhysioData(path=fname)
+    
+    def _get_event_data(fname):
+        """ Function to return a MockEventData object
+        """
+        return MockEventData(path=fname)
+
+    def _get_physio_acq_time(fname):
+    """ Mock a function to retrieve the physio acquisition time:
+        given the file name, it will be run number x TIME_BETWEEN_RUNS
+    """
+        try:
+            run_no = int(fname.split('_')[-1])
+        except ValueError:
+            raise FileNotFoundError('This is not a valid filename')
+        return timedelta(seconds=run_no * TIME_BETWEEN_RUNS)
+
+    # run convert_session:
+    phys_files = ['phys_{}'.format(i) for i in range(N_RUNS)]
+    bids_dir = 'foo'
+    sub = '01'
+    s2b.convert_edf_session(phys_files, bids_dir, sub,
+                            get_physio_data=_get_physio_data,
+                            get_event_data=_get_event_data,
+                            get_physio_acq_time=_get_physio_acq_time,
+                            outdir='bar', overwrite=True)
